@@ -1,7 +1,10 @@
 $PROB
 # Example population PK model
 
-$PARAM TVKA = 0.5, TVCL = 1, TVV = 24, WT=70
+$PARAM TVKA = 0.5, TVCL = 1, TVV = 24
+
+$PARAM @covariates
+WT = 70
 
 $PKMODEL cmt="GUT CENT", depot=TRUE
 
@@ -23,4 +26,4 @@ capture DV = IPRED*exp(EPS(1));
 
 $CAPTURE CL V ECL
 
-  
\ No newline at end of file
+  
